<?php
namespace wcf\acp\form;
use wcf\data\jwt\JWTService;
use wcf\data\jwt\JWTServiceAction;
use wcf\form\AbstractForm;
use wcf\system\exception\IllegalLinkException;
use wcf\system\WCF;

/**
 * Shows the jwt service edit form.
 * 
 * @author	Franz Reiter (Howaner)
 * @copyright	2019 Franz Reiter
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	de.howaner.jwt
 */
class JWTServiceEditForm extends JWTServiceAddForm {
	/**
	 * @inheritDoc
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.jwtservice';
	
	/**
	 * @inheritDoc
	 */
	public $neededPermissions = ['admin.configuration.canManageJwtServices'];
	
	/**
	 * jwt service id
	 * @var	integer
	 */
	public $jwtServiceID = 0;
	
	/**
	 * jwt service object
	 * @var	JWTService
	 */
	public $jwtService = null;
	
	/**
	 * @inheritDoc
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->jwtServiceID = intval($_REQUEST['id']);
		$this->jwtService = new JWTService($this->jwtServiceID);
		if (!$this->jwtService->jwtServiceID) {
			throw new IllegalLinkException();
		}
	}
	
	/**
	 * @inheritDoc
	 */
	public function save() {
		AbstractForm::save();
		
		// update bbcode
		$this->objectAction = new JWTServiceAction([$this->jwtServiceID], 'update', [
			'data' => array_merge($this->additionalFields, [
				'name' => $this->name,
				'algorithm' => $this->algorithm,
				'secret' => $this->secret,
				'redirectURL' => $this->redirectURL,
				'lifetime' => $this->lifetime
			])
		]);
		$this->objectAction->executeAction();
		
		$this->saved();
		
		// show success message
		WCF::getTPL()->assign('success', true);
	}
	
	/**
	 * @inheritDoc
	 */
	public function readData() {
		parent::readData();
		
		if (empty($_POST)) {
			$this->name = $this->jwtService->name;
			$this->algorithm = $this->jwtService->algorithm;
			$this->secret = $this->jwtService->secret;
			$this->redirectURL = $this->jwtService->redirectURL;
			$this->lifetime = $this->jwtService->lifetime;
		}
	}
	
	/**
	 * @inheritDoc
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign([
			'jwtService' => $this->jwtService,
			'action' => 'edit'
		]);
	}
}

