<?php
namespace wcf\data\jwt;
use wcf\data\DatabaseObject;

require_once WCF_DIR . 'lib/system/api/php-jwt/vendor/autoload.php';
use \Firebase\JWT\JWT;

/**
 * Represents a JWT Service.
 * 
 * @author	Franz Reiter (Howaner)
 * @copyright	2019 Franz Reiter
 * @license	GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @package	de.howaner.jwt
 * 
 * @property-read	integer		$jwtServiceID	unique id of the jwt service
 * @property-read   string      $name        name of the jwt service
 * @property-read   string      $algorithm   algorithm that should be used for signature
 * @property-read   string      $secret      secret of the jwt service
 * @property-read   string      $redirectURL url to redirect to after login
 * @property-read   int         $lifetime    lifetime of the token in seconds
 * @property-read   bool        $enabled     is this jwt service enabled?
 */
class JWTService extends DatabaseObject {

	/**
	 * database table for this object
	 * @var	string
	 */
	protected static $databaseTableName = 'jwt_service';
	
	/**
	 * name of the primary index column
	 * @var	string
	 */
	protected static $databaseTableIndexName = 'jwtServiceID';

	public static function getSupportedAlgorithms() {
		$algs = JWT::$supported_algs;
		return array_keys($algs);
	}
	
}
