<?php
namespace wcf\page;

use wcf\system\WCF;
use wcf\system\exception\PermissionDeniedException;
use wcf\system\exception\IllegalLinkException;
use wcf\data\jwt\JWTService;
use wcf\data\jwt\JWTServiceList;
use wcf\util\HeaderUtil;

require_once WCF_DIR . 'lib/system/api/php-jwt/vendor/autoload.php';
use \Firebase\JWT\JWT;

class JwtPage extends AbstractPage {

	/**
	 * indicates if you need to be logged in to access this page
	 * @var	boolean
	 */
	public $loginRequired = true;

	/**
	 * enables template usage
	 * @var	boolean
	 */
	public $useTemplate = false;

	public $jwtServiceName = "";

	public function readParameters() {
		parent::readParameters();

		if (isset($_GET['service'])) $this->jwtServiceName = $_GET['service'];
	}

	public function show() {
		if (!WCF::getUser()->userID) {
			$this->forceLogin();
			throw new PermissionDeniedException();  // Should never be called because forceLogin() exits the application.
		}

		$jwtService = JWTServiceList::getServiceByName($this->jwtServiceName);
		if ($jwtService == null) {
			throw new IllegalLinkException();
		}

		$time = time();
		$token = array(
			"iss" => "Rewinside TV",
			"aud" => $jwtService->name,
			"iat" => $time,
			"nbf" => $time,
			"exp" => $time + $jwtService->lifetime,
			"sub" => WCF::getUser()->uuid
		);
		$jwt = JWT::encode($token, $jwtService->secret);

		$url = str_replace("{token}", $jwt, $jwtService->redirectURL);
		HeaderUtil::redirect($url, true, true);
		exit;
	}

	public function assignVariables() {
		parent::assignVariables();
	}


}